import { HTMLServerConfig, ServerConfig, VideoResolutionType } from '../../../peertube-models';
/**
 *
 * Used to send the server config to clients (using REST/API or plugins API)
 * We need a singleton class to manage config state depending on external events (to build menu entries etc)
 *
 */
declare class ServerConfigManager {
    private static instance;
    private serverCommit;
    private homepageEnabled;
    private constructor();
    init(): Promise<void>;
    updateHomepageState(content: string): void;
    getHTMLServerConfig(): Promise<HTMLServerConfig>;
    getServerConfig(ip?: string): Promise<ServerConfig>;
    getRegisteredThemes(): {
        npmName: string;
        name: string;
        version: string;
        description: string;
        css: string[];
        clientScripts: {
            [name: string]: import("../../../peertube-models").ClientScriptJSON;
        };
    }[];
    getRegisteredPlugins(): {
        npmName: string;
        name: string;
        version: string;
        description: string;
        clientScripts: {
            [name: string]: import("../../../peertube-models").ClientScriptJSON;
        };
    }[];
    getEnabledResolutions(type: 'vod' | 'live'): VideoResolutionType[];
    private getIdAndPassAuthPlugins;
    private getExternalAuthsPlugins;
    static get Instance(): ServerConfigManager;
}
export { ServerConfigManager };
//# sourceMappingURL=server-config-manager.d.ts.map